@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (C) 2023 Callum Dickinson
 #
 # Buildarr is free software: you can redistribute it and/or modify it under the terms of the
@@ -38,10 +36,11 @@ from typing import (
     get_args as get_type_args,
     get_origin as get_type_origin,
 )
+from uuid import UUID
 
 import yaml
 
-from pydantic import BaseModel, SecretStr
+from pydantic import AnyUrl, BaseModel, SecretStr
 from pydantic.validators import _VALIDATORS
 from typing_extensions import Self
 
@@ -50,6 +49,8 @@ from ..plugins import Secrets
 from ..types import BaseEnum, BaseIntEnum
 from .types import RemoteMapEntry
 
+OPTIONAL_TYPE_UNION_SIZE = 2
+
 
 class ConfigBase(BaseModel, Generic[Secrets]):
     """
@@ -211,7 +212,7 @@ class ConfigBase(BaseModel, Generic[Secrets]):
                                         "'value' attribute not included "
                                         f"for remote field '{remote_attr_name}'"
                                         "and 'field_default' not defined in local attribute",
-                                    )
+                                    ) from None
                             break
                     else:
                         if attr_metadata.get("optional", False):
@@ -384,9 +385,10 @@ class ConfigBase(BaseModel, Generic[Secrets]):
         already_logged: Set[str] = set()
         for attr_name, remote_attr_name, attr_metadata in remote_map:
             # Determine the correct attribute formatter function used in logging.
-            formatter: Callable[[Any], str] = lambda v: repr(
-                attr_metadata.get("formatter", self._format_attr)(v),
-            )
+            def formatter(v: Any) -> str:
+                nonlocal attr_metadata
+                return repr(attr_metadata.get("formatter", self._format_attr)(v))
+
             # Determine whether or not the attribute should be set in
             # the remote attribute dictonary.
             if (
@@ -526,6 +528,9 @@ class ConfigBase(BaseModel, Generic[Secrets]):
         * `is_field` (`bool`, default: `False`)
             * Denotes whether the remote value is stored in an *Arr API-style field
               for remote value writing purposes
+        * `check_unmanaged` (`bool`, default: (function-supplied value))
+            * Remote map entry-supplied override for the function-supplied
+              `check_unmanaged` parameter
         * `set_unchanged` (`bool`, default: (function-supplied value))
             * Remote map entry-supplied override for the function-supplied
               `set_unchanged` parameter
@@ -546,16 +551,20 @@ class ConfigBase(BaseModel, Generic[Secrets]):
         for attr_name, remote_attr_name, attr_metadata in remote_map:
             #
             set_value = False
+
             #
-            formatter: Callable[[Any], str] = lambda v: repr(
-                attr_metadata.get("formatter", self._format_attr)(v),
-            )
+            def formatter(v: Any) -> str:
+                return repr(attr_metadata.get("formatter", self._format_attr)(v))
+
             #
             remote_value = getattr(remote, attr_name)
             # Handle the case where the attribute is managed, either
             # by virtue of it being explicitly set in the Buildarr config,
             # or check_unmanaged is set to True.
-            if check_unmanaged or attr_name in self.__fields_set__:
+            if (
+                attr_metadata.get("check_unmanaged", check_unmanaged)
+                or attr_name in self.__fields_set__
+            ):
                 local_value = getattr(self, attr_name)
                 # If the local and remote attributes are set to the same
                 # value, unless set_unchanged is set to True, do nothing.
@@ -638,10 +647,14 @@ class ConfigBase(BaseModel, Generic[Secrets]):
         """
         if isinstance(value, BaseEnum):
             return value.to_name_str()
+        elif isinstance(value, AnyUrl):
+            return str(value)
         elif isinstance(value, SecretStr):
             return str(value)
         elif isinstance(value, Path):
             return str(value)
+        elif isinstance(value, UUID):
+            return str(value)
         elif isinstance(value, list):
             return [cls._format_attr(v) for v in value]
         elif isinstance(value, set):
@@ -671,9 +684,13 @@ class ConfigBase(BaseModel, Generic[Secrets]):
         elif get_type_origin(attr_type) is Union:
             attr_union_types = get_type_args(attr_type)
             #
-            if len(attr_union_types) == 2 and type(None) in attr_union_types and value is not None:
+            if (
+                len(attr_union_types) == OPTIONAL_TYPE_UNION_SIZE
+                and type(None) in attr_union_types
+                and value is not None
+            ):
                 return cls._decode_attr(
-                    [t for t in attr_union_types if t is not type(None)][0],  # noqa: E721
+                    [t for t in attr_union_types if t is not type(None)][0],
                     value,
                 )
         elif issubclass(attr_type, BaseEnum):
@@ -693,8 +710,12 @@ class ConfigBase(BaseModel, Generic[Secrets]):
         """
         if isinstance(value, BaseEnum):
             return value.value
+        elif isinstance(value, AnyUrl):
+            return str(value)
         elif isinstance(value, SecretStr):
             return value.get_secret_value()
+        elif isinstance(value, UUID):
+            return str(value)
         elif isinstance(value, (list, set)):
             return [cls._encode_attr(v) for v in value]
         return value
@@ -712,6 +733,36 @@ class ConfigBase(BaseModel, Generic[Secrets]):
         return yaml.safe_dump(json.loads(self.json(*args, **kwargs)))
 
     class Config:
+        """
+        Buildarr base Pydantic model configuration.
+
+        Sets some required configuration parameters for
+        serialisation and parsing to work correctly.
+
+        To set additional parameters in your implementing class, subclass this class:
+
+        ```python
+        from __future__ import annotations
+
+        from typing import TYPE_CHECKING
+        from buildarr.config import ConfigBase
+
+        if TYPE_CHECKING:
+            from .secrets import ExampleSecrets
+            class ExampleConfigBase(ConfigBase[ExampleSecrets]):
+                ...
+        else:
+            class ExampleConfigBase(ConfigBase):
+                ...
+
+        class ExampleConfig(ExampleConfigBase):
+            ...
+
+            class Config(ExampleConfigBase.Config):
+                ...  # Add model configuration attributes here.
+        ```
+        """
+
         # Add default JSON encoders for custom, non-default and otherwise non-specified
         # classes so serialisation can work.
         json_encoders = {
@@ -720,10 +771,15 @@ class ConfigBase(BaseModel, Generic[Secrets]):
             PurePosixPath: str,
             SecretStr: lambda v: v.get_secret_value(),
         }
+
         # Required to avoid coersion with same-name but different-typed fields
         # in objects for which there are multiple types that can be defined.
         smart_union = True
 
+        # When aliases are defined, allow attributes to be referenced by their
+        # internal name, as well as the alias.
+        allow_population_by_field_name = True
+
 
 def _validate_pure_posix_path(v: Any) -> PurePosixPath:
     """
