@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (C) 2023 Callum Dickinson
 #
 # Buildarr is free software: you can redistribute it and/or modify it under the terms of the
@@ -24,7 +22,7 @@ from __future__ import annotations
 from datetime import datetime
 from typing import Any, Dict, List, Literal, Mapping, Optional, Set, Tuple, Type, Union
 
-from pydantic import ConstrainedInt, Field, HttpUrl, NameEmail, SecretStr
+from pydantic import AnyHttpUrl, ConstrainedInt, Field, NameEmail, SecretStr
 from typing_extensions import Annotated, Self
 
 from buildarr.config import RemoteMapEntry
@@ -441,7 +439,7 @@ class DiscordConnection(Connection):
     Type value associated with this kind of connection.
     """
 
-    webhook_url: HttpUrl
+    webhook_url: AnyHttpUrl
     """
     Discord server webhook URL.
     """
@@ -748,7 +746,7 @@ class GotifyConnection(Connection):
     Type value associated with this kind of connection.
     """
 
-    server: HttpUrl
+    server: AnyHttpUrl
     """
     Gotify server URL. (e.g. `http://gotify.example.com:1234`)
     """
@@ -1382,7 +1380,7 @@ class SlackConnection(Connection):
     Type value associated with this kind of connection.
     """
 
-    webhook_url: HttpUrl
+    webhook_url: AnyHttpUrl
     """
     Webhook URL for the Slack channel to send to.
     """
@@ -1621,7 +1619,7 @@ class WebhookConnection(Connection):
     Type value associated with this kind of connection.
     """
 
-    url: HttpUrl
+    url: AnyHttpUrl
     """
     Webhook URL to send notifications to.
     """
@@ -1781,16 +1779,15 @@ class SonarrConnectSettingsConfig(SonarrConfigBase):
                 )
                 changed = True
             #
-            else:
-                if connection._update_remote(
-                    tree=connection_tree,
-                    secrets=secrets,
-                    remote=remote.definitions[connection_name],  # type: ignore[arg-type]
-                    tag_ids=tag_ids,
-                    connection_id=connection_ids[connection_name],
-                    connection_name=connection_name,
-                ):
-                    changed = True
+            elif connection._update_remote(
+                tree=connection_tree,
+                secrets=secrets,
+                remote=remote.definitions[connection_name],  # type: ignore[arg-type]
+                tag_ids=tag_ids,
+                connection_id=connection_ids[connection_name],
+                connection_name=connection_name,
+            ):
+                changed = True
         #
         for connection_name, connection in remote.definitions.items():
             if connection_name not in self.definitions:
