@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (C) 2023 Callum Dickinson
 #
 # Buildarr is free software: you can redistribute it and/or modify it under the terms of the
@@ -23,7 +21,7 @@ from __future__ import annotations
 
 from typing import Any, Dict, List, Literal, Mapping, Optional, Set, Tuple, Type, Union
 
-from pydantic import Field, HttpUrl, PositiveInt
+from pydantic import AnyHttpUrl, Field, PositiveInt
 from typing_extensions import Annotated, Self
 
 from buildarr.config import RemoteMapEntry
@@ -301,7 +299,8 @@ class TorrentIndexer(Indexer):
         download_client_ids: Mapping[str, int],
         tag_ids: Mapping[str, int],
     ) -> List[RemoteMapEntry]:
-        return super()._get_base_remote_map(download_client_ids, tag_ids) + [
+        return [
+            *super()._get_base_remote_map(download_client_ids, tag_ids),
             ("minimum_seeders", "minimumSeeders", {"is_field": True}),
             ("seed_ratio", "seedRatio", {}),
             ("seed_time", "seedTime", {}),
@@ -342,7 +341,7 @@ class NewznabIndexer(UsenetIndexer):
     Type value associated with this kind of indexer.
     """
 
-    url: HttpUrl
+    url: AnyHttpUrl
     """
     URL of the Newznab-compatible indexing site.
     """
@@ -468,7 +467,7 @@ class BroadcasthenetIndexer(TorrentIndexer):
     Type value associated with this kind of indexer.
     """
 
-    api_url: HttpUrl = "https://api.broadcasthe.net"  # type: ignore[assignment]
+    api_url: AnyHttpUrl = "https://api.broadcasthe.net"  # type: ignore[assignment]
     """
     BroadcasTheNet API URL.
     """
@@ -507,7 +506,7 @@ class FilelistIndexer(TorrentIndexer):
     FileList account API key.
     """
 
-    api_url: HttpUrl = "https://filelist.io"  # type: ignore[assignment]
+    api_url: AnyHttpUrl = "https://filelist.io"  # type: ignore[assignment]
     """
     FileList API URL.
 
@@ -591,7 +590,7 @@ class HdbitsIndexer(TorrentIndexer):
     HDBits API key assigned to the account.
     """
 
-    api_url: HttpUrl = "https://hdbits.org"  # type: ignore[assignment]
+    api_url: AnyHttpUrl = "https://hdbits.org"  # type: ignore[assignment]
     """
     HDBits API URL.
 
@@ -652,7 +651,7 @@ class NyaaIndexer(TorrentIndexer):
     Type value associated with this kind of indexer.
     """
 
-    website_url: HttpUrl
+    website_url: AnyHttpUrl
     """
     HTTPS URL for accessing Nyaa.
     """
@@ -688,7 +687,7 @@ class RarbgIndexer(TorrentIndexer):
     Type value associated with this kind of indexer.
     """
 
-    api_url: HttpUrl
+    api_url: AnyHttpUrl
     """
     RARBG API url.
     """
@@ -784,7 +783,7 @@ class TorrentleechIndexer(TorrentIndexer):
     # NOTE: automatic_search and interactive_search are not supported
     # by this indexer, therefore its value is ignored.
 
-    website_url: HttpUrl = "http://rss.torrentleech.org"  # type: ignore[assignment]
+    website_url: AnyHttpUrl = "http://rss.torrentleech.org"  # type: ignore[assignment]
     """
     TorrentLeech feed API URL.
     """
@@ -815,7 +814,7 @@ class TorznabIndexer(TorrentIndexer):
     Type value associated with this kind of indexer.
     """
 
-    url: HttpUrl
+    url: AnyHttpUrl
     """
     URL of the Torznab-compatible indexing site.
     """
@@ -1100,17 +1099,16 @@ class SonarrIndexersSettingsConfig(SonarrConfigBase):
                 )
                 changed = True
             #
-            else:
-                if indexer._update_remote(
-                    tree=indexer_tree,
-                    secrets=secrets,
-                    remote=remote.definitions[indexer_name],  # type: ignore[arg-type]
-                    download_client_ids=download_client_ids,
-                    tag_ids=tag_ids,
-                    indexer_id=indexer_ids[indexer_name],
-                    indexer_name=indexer_name,
-                ):
-                    changed = True
+            elif indexer._update_remote(
+                tree=indexer_tree,
+                secrets=secrets,
+                remote=remote.definitions[indexer_name],  # type: ignore[arg-type]
+                download_client_ids=download_client_ids,
+                tag_ids=tag_ids,
+                indexer_id=indexer_ids[indexer_name],
+                indexer_name=indexer_name,
+            ):
+                changed = True
         #
         for indexer_name, indexer in remote.definitions.items():
             if indexer_name not in self.definitions:
